@@ -11,44 +11,44 @@
 #' FALSE (by default) returns only distinct data regardless of the seed.
 #' @param genome_seq Logical value (TRUE/FALSE) to show/hide this column
 #' ("FALSE" by default).
-#' 
+#'
 #' @param triplestore Object of class triplestore_access which manages database
 #' access.
-#' 
+#'
 #' @return Data frame. Columns: "seed_id" (optional), "transcriptome_id",
-#' "genome_seq" (optional). 
-#' 
-#' @examples 
-#' 
+#' "genome_seq" (optional).
+#'
+#' @examples
+#'
 #' # Create triplestore object
-#' triplestore <- triplestore_access$new()
-#' 
+#' avidaDB <- triplestore_access$new()
+#'
 #' # Set access options
-#' triplestore$set_access_options(
+#' avidaDB$set_access_options(
 #'   url = "https://graphdb.fortunalab.org",
 #'   user = "public_avida",
 #'   password = "public_avida",
 #'   repository = "avidaDB_test"
 #' )
-#' 
+#'
 #' # Single transcriptome
 #' get_genome_id_from_transcriptome_id(
 #'   transcriptome_id = 1,
-#'   triplestore = triplestore
+#'   triplestore = avidaDB
 #' )
-#' 
+#'
 #' # More than one transcriptome
 #' get_genome_id_from_transcriptome_id(
 #'   transcriptome_id = c(1, 2, 3),
 #'   genome_seq = TRUE,
-#'   triplestore = triplestore
+#'   triplestore = avidaDB
 #' )
-#' 
+#'
 #' # At seed_1 and seed_2
 #' get_genome_id_from_transcriptome_id(
 #'   transcriptome_id = 1,
 #'   seed_id = c(1, 2),
-#'   triplestore = triplestore
+#'   triplestore = avidaDB
 #' )
 #'
 #' @export
@@ -68,24 +68,24 @@ get_genome_id_from_transcriptome_id <- function(transcriptome_id, seed_id = FALS
 
                   "    # transcriptomes \n",
                   "    #transcriptome#\n\n",
-                  
+
                   "    # organism\n",
                   "    ?organism_id ONTOAVIDA:00000004 ?seq .\n\n",
-                  
+
                   "    # container\n",
                   "    ?seq ?executes_at_seed_id ?transcriptome_id .\n\n",
-                  
+
                   "    # seed\n",
                   "    #executes_at_seed#\n",
                   "    ?executes_at_seed rdfs:subPropertyOf rdfs:member .\n",
                   "    FILTER(?executes_at_seed_id != rdfs:member ) .\n\n",
-                  
+
                   "    # has component \n",
                   "    ?organism_id RO:0002180 ?genome_id .\n\n",
-                  
+
                   "    # genome seq\n",
                   "    ?genome_id ONTOAVIDA:00000122 ?genome_seq .\n\n",
-                  
+
                   "}"
   )
 
@@ -99,12 +99,15 @@ get_genome_id_from_transcriptome_id <- function(transcriptome_id, seed_id = FALS
   # Submit query
   response <- triplestore$submit_query(query = query)
 
-  if (nrow(response) > 0) {
+  if (is.null(response))
+    return(invisible(NULL))
+  
+  if (nrow(response)>0) {
     # Remove prefixes
     response <- remove_prefix(prefix = ontoavida_prefix(), data = response)
     response <- remove_prefix(prefix = rdf_prefix(), data = response)
     response <- clean_at_seed_id (data = response, seed_id = seed_id, at_seed_vars = "executes_at_seed_id")
-    
+
   }
 
   # Return response
