@@ -9,7 +9,7 @@ all_at_seed <- function() {
 
 #' validate access_options
 #'
-#' 
+#'
 #'
 #' @noRd
 #'
@@ -44,10 +44,10 @@ validate_logic_operation <- function(logic_operation) {
 #' @param types a integer value
 #'
 #' @noRd
-#' 
+#'
 validate_param <- function(param, value, types) {
   if (!(get_data_type(value = value) %in% types)) {
-    stop(paste0("Data type is not supported for ", param))
+    message(paste0("Data type is not supported for ", param))
   }
 }
 
@@ -60,9 +60,10 @@ validate_param <- function(param, value, types) {
 #'  1: when value is a single logical value
 #'  2: when value is numeric or a vector of integer
 #'  3: when value is character of a verctor of character
+#'  4: when value is of class triplestore_access
 #'
 #' @noRd
-#' 
+#'
 get_data_type <- function(value) {
   if (is.logical(value) && length(value) == 1) {
     return(1)
@@ -70,6 +71,8 @@ get_data_type <- function(value) {
     return(2)
   } else if (is.character(value) && length(value) > 0) {
     return(3)
+  } else if ("triplestore_access" %in% class(value)) {
+    return(4)
   } else {
     return(0)
   }
@@ -79,20 +82,20 @@ get_data_type <- function(value) {
 #' @param seed_id logical, or integer
 #' @param at_seed_vars a vector of character
 #' @param query a string of character
-#' 
+#'
 #' @return query a string of character
-#' 
+#'
 #' @noRd
-#' 
+#'
 replace_at_seed_id <- function(seed_id, at_seed_vars, query) {
-  
+
   all_at_seed_vars <- all_at_seed()
   names(all_at_seed_vars) <- gsub("_id","", names(all_at_seed_vars))
-  
+
   if(isTRUE(seed_id)) {
-    seed_id <- c(1:1000)  
+    seed_id <- c(1:1000)
   }
-  
+
   for(this_at_seed in at_seed_vars) {
     if(this_at_seed %in% names(all_at_seed_vars)) {
       if(get_data_type(seed_id) == 2) {
@@ -101,19 +104,19 @@ replace_at_seed_id <- function(seed_id, at_seed_vars, query) {
       }
     }
   }
-  
+
   if(get_data_type(value = seed_id) == 1 || isFALSE(seed_id)) {
     query <- gsub("#encodes_at_seed_id#", "", query)
     query <- gsub("#encodes_at_seed#", "", query)
     #query <- gsub("[?]encodes_at_seed_id", "ONTOAVIDA:00001198", query)
     query <- gsub("#encodes#", "ONTOAVIDA:00001198", query)
-    
+
     query <- gsub("#executes_at_seed_id#", "", query)
     query <- gsub("#executes_at_seed#", "", query)
     #query <- gsub("[?]executes_at_seed_id", "ONTOAVIDA:00000004", query)
     query <- gsub("#executes#", "ONTOAVIDA:00000004", query)
   }
-  
+
   return(query)
 }
 #' replace_data
@@ -125,7 +128,7 @@ replace_at_seed_id <- function(seed_id, at_seed_vars, query) {
 #' @return the query once the param has been replaced
 #'
 #' @noRd
-#' 
+#'
 replace_data <- function(param, value, query) {
   # Set vars
   search_param <- paste0("#", param, "#")
@@ -137,10 +140,10 @@ replace_data <- function(param, value, query) {
     paste0(paste0("ONTOAVIDA:", param, "_", format(value, scientific = FALSE, trim = TRUE)), collapse = " ")
 
   # Id vars
-  id_vars <- c("encodes_at_seed", "executes_at_seed", "seed", "genome", "transcriptome", "tandem", "phenotype")
+  id_vars <- c("encodes_at_seed", "executes_at_seed", "seed", "genome", "transcriptome", "tandem", "phenotype", "avida_experiment", "organism", "docker_image")
 
   # Triple vars
-  triple_vars <- c("genome_seq", "transcriptome_seq", "transcriptome_pos", "tandem_seq", "tandem_pos")
+  triple_vars <- c("genome_seq", "transcriptome_seq", "transcriptome_pos", "tandem_seq", "tandem_pos", "doi", "description")
 
   # Replace identifier
   if (param %in% id_vars) {
@@ -207,6 +210,29 @@ replace_data <- function(param, value, query) {
     query <- gsub("#tandem_pos#", "?tandem_pos", query)
   }
 
+  # Replace doi
+  if (param == "doi") {
+    value <- gsub("https://doi.org/", "", value)
+    if((get_data_type(value) == 1 && isTRUE(value)) || get_data_type(value) != 1 ) {
+      query <- gsub("#doi#", "?doi", query)
+    } else {
+      query <- gsub("#doi#", "", query)
+    }
+    if(get_data_type(value) != 1) {
+      query <- gsub("#doi_triple#", paste0("VALUES ?doi { ", paste(paste0('"', value, '"'), collapse = " "), " } ."), query)
+    }
+  }
+
+  # Replace description
+  if (param == "description") {
+    query <- if (isTRUE(value))
+      gsub("#description#", "?description", query)
+    else
+      gsub("#description#", "", query)
+  }
+
+
+
   # Return query
   return(query)
 }
@@ -217,20 +243,20 @@ replace_data <- function(param, value, query) {
 #' @param seed_id logical, or integer
 #' @param at_seed_vars a vector of character
 #' @return a data frame
-#' 
+#'
 #' @noRd
-#' 
+#'
 clean_at_seed_id <- function(data, seed_id, at_seed_vars){
   if(get_data_type(value = seed_id) == 1 && isFALSE(seed_id)) {
     return(data)
   }
-  
+
   for(this_at_seed in at_seed_vars) {
     if(this_at_seed %in% names(all_at_seed()) && this_at_seed %in% names(data)) {
       if(get_data_type(value = seed_id) == 2 || isTRUE(seed_id)) {
         data <- data %>% rename(seed_id = all_of(this_at_seed))
         data <- data %>% rowwise() %>% mutate(seed_id = paste0("seed_", as.integer(seed_id) - as.integer(all_at_seed()[this_at_seed][[1]])))
-      }      
+      }
     }
   }
 
@@ -269,10 +295,10 @@ show_hide_vars <- function(vars, query) {
 remove_prefix <- function(prefix, data) {
   # add _ to rdf_prefix
   if(prefix == rdf_prefix())
-    prefix = paste0(rdf_prefix(), "_") 
- 
+    prefix = paste0(rdf_prefix(), "_")
+
   # Column names
-  cols <- c("organism_id", "seed_id", "encodes_at_seed_id","executes_at_seed_id", "genome_id", "transcriptome_id", "tandem_id", "phenotype_id", "genome_id_ancestor", "genome_id_mutant", "organism_id_ancestor", "organism_id_mutant", "genome_id_wild_type", "genome_seq_wild_type")
+  cols <- c("organism_id", "seed_id", "encodes_at_seed_id","executes_at_seed_id", "genome_id", "transcriptome_id", "tandem_id", "phenotype_id", "genome_id_ancestor", "genome_id_mutant", "organism_id_ancestor", "organism_id_mutant", "genome_id_wild_type", "genome_seq_wild_type", "avida_experiment_id", "docker_image_id")
 
   # Replace prefix with empty string
   for (col_name in cols) {
@@ -303,21 +329,21 @@ show_hide_columns <- function(vars_list, data) {
           data[i, "phenotype_binary"] <- paste(as.integer(intToBits(gsub("phenotype_", "", data[i, "phenotype_id"])))[9:1], collapse = "")
         }
       }
-      
+
       if (v == "transcriptome_pos") {
         data <- data %>%
           dplyr::rowwise() %>%
           dplyr::mutate(transcriptome_pos = decompress_sequence(.data$transcriptome_pos))
         data <- as.data.frame(data)
       }
-      
+
       if (v == "transcriptome_seq") {
         data <- data %>%
           dplyr::rowwise() %>%
           dplyr::mutate(transcriptome_seq = decompress_sequence(.data$transcriptome_seq))
         data <- as.data.frame(data)
       }
-      
+
     } else {
       data[, v] <- NULL
     }
@@ -335,7 +361,7 @@ show_hide_columns <- function(vars_list, data) {
 #' @return character
 #'
 #' @noRd
-#' 
+#'
 decompress_sequence <- function(x) {
   # convert string to a vector of 1 character
   # s <- strsplit(x, "")[[1]]
@@ -352,7 +378,7 @@ decompress_sequence <- function(x) {
 #' logic_operation_to_binary
 #'
 #' @param logic_operation List of logical functions withing the following:
-#' "equals", "exclusive-or", "not-or", "and-not", "or", "orn-not", "and", 
+#' "equals", "exclusive-or", "not-or", "and-not", "or", "orn-not", "and",
 #' "not-and", "not".
 #'
 #' @return string of character
@@ -365,7 +391,7 @@ logic_operation_to_binary <- function(logic_operation) {
 #' logic_operation_to_integer
 #'
 #' @param logic_operation List of logical functions withing the following:
-#' "equals", "exclusive-or", "not-or", "and-not", "or", "orn-not", "and", 
+#' "equals", "exclusive-or", "not-or", "and-not", "or", "orn-not", "and",
 #' "not-and", "not".
 #'
 #' @return integer
@@ -382,7 +408,7 @@ capture_error <- function(code, otherwise = NULL, quiet = TRUE) {
     error = function(e) {
       if (!quiet)
         message(e$message)
-      
+
       list(result = otherwise, error = e)
     },
     interrupt = function(e) {
@@ -396,24 +422,21 @@ safely <- function(.f, otherwise = NULL, quiet = TRUE) {
 }
 
 get_message_from_status_code <- function(status_code, url, repository) {
-  
+
   status_message <- paste0(
-    "Server responded with status code '",
-    status_code,
-    " - ",
     switch(
       as.character(status_code),
       "400" = "Bad request':\n- The server cannot process your request, check you provided a valid url and respository name.",
-      "401" = "Not authorized':\n- Please provide a valid user and password for access options.",
-      "403" = "Forbidden':",
-      "404" = "Not found':\n- Check that server url and repository name provided are valid and have a correct syntax.",
-      "500" = "Internal server error':",
-      "522" = "Connection timed out reached':\n- Check your network connection.\n- Some requests might require a high number of operations and, therefore, more time to be processed,\n  try requesting less elements and/or increasing timeout limit (seconds).",
-      "526" = "It seems that the server SSL certificate is not valid':",
-      "unknown':\n- Please, try in a few minutes."
+      "401" = "Not authorized. Please provide a valid url, user, password, and repository name for access options.",
+      "403" = "You are trying to access a resource that doesn't exist or is forbidden. Please check the provided URL and repository name.",
+      "404" = "Not found. Please double check that server url and repository name provided are valid and have a correct syntax.",
+      "500" = "Sorry, we are having some interna issue with our service.",
+      "522" = "Connection timed out reached. Please check your internet connection. Some requests may take longer to process, so consider requesting fewer items or increasing the timeout limit (in seconds).",
+      "526" = "Sorry, we are having some internal issue with our service.",
+      "Ups! Something went bad, try in a few minutes."
     )
   )
-  
+
   if (status_code == "500" || status_code == "403") {
     if (endsWith(url, "/") == TRUE || grepl("/", repository) == TRUE) {
       status_message <- paste0(
@@ -423,30 +446,26 @@ get_message_from_status_code <- function(status_code, url, repository) {
       )
     }
   }
-  
+
   status_message <- paste0(
     status_message,
-    "\n- If error persists, please contact server administrator."
+    " If error persists, please contact server administrator."
   )
-  
+
   return(status_message)
 }
 
 server_no_response <- function(resource_url) {
   return(
     paste0(
-      "There is no response from server (", resource_url, "):\n",
-      "- The service might be temporarily unavailable or too busy. Please try again in a few minutes.\n",
-      "- Check that server url and repository name provided have a correct syntax.\n",
-      "- Please check you are connected to de network and can access any web site.\n",
-      "- If error persists, please contact to server administrator."
+      "There is no response from service (", resource_url, "). Check that the url provided is correct. If error persists, please contact to server administrator."
     )
   )
 }
 
 
 #' @description Server API POST method
-#' 
+#'
 #' @param url A single URL
 #' @param repository Repository name
 #' @param authentication what to do if the site exists but the
@@ -455,15 +474,20 @@ server_no_response <- function(resource_url) {
 #'        arises a warning message will be displayed. Default is `FALSE`.
 #' @param max_seconds Number of seconds to consider a timeout scenario.
 #' #'
-#' @return data frame 
+#' @return data frame
 #'
 #' @noRd
 server_api_post <- function(url, repository, authentication, query, quiet = FALSE, max_seconds = 20) {
   
+  if (!curl::has_internet()) {
+    message("No internet connection.")
+    return(invisible(NULL))
+  }
+
   sPOST <- safely(httr::POST)
-  
+
   resource_url <- paste0(url, "/repositories/", repository)
-  
+
   res <- sPOST(
     url = resource_url,
     authentication,
@@ -474,28 +498,33 @@ server_api_post <- function(url, repository, authentication, query, quiet = FALS
     timeout(max_seconds)
   )
   
+  if (is.null(res$result)) {
+    message("The service is not available in this moment, please try it later, if the problem persists contact the administrator.")
+    return(invisible(NULL))
+  }
+
   if (is.null(res$result) || ((httr::status_code(res$result) %/% 200) != 1)) {
-    
+
     if (is.null(res$result)) {
       if (!is.null(res$error) && grepl("imeout", res$err)) {
-        if (!quiet) stop(call. = FALSE, get_message_from_status_code(522, url, repository))
+        if (!quiet) message(get_message_from_status_code(522, url, repository)) #stop(call. = FALSE, get_message_from_status_code(522, url, repository))
       } else
-          stop(call. = FALSE, server_no_response(resource_url))
+          message(server_no_response(resource_url)) #stop(call. = FALSE, server_no_response(resource_url))
     }
-      
-    
+
+
     if (((httr::status_code(res$result) %/% 200) != 1)) {
-      if (!quiet) stop(call. = FALSE, get_message_from_status_code(httr::status_code(res$result), url, repository))
+      if (!quiet) message(get_message_from_status_code(httr::status_code(res$result), url, repository)) # stop(call. = FALSE, get_message_from_status_code(httr::status_code(res$result), url, repository))
     }
-    
+
   } else {
     return(utils::read.csv(textConnection(httr::content(res$result, as = "text")), stringsAsFactors = FALSE))
   }
-  
+
 }
 
 #' @description Server API GET method.
-#' 
+#'
 #' @param url A single URL.
 #' @param resource Server resource to be requested.
 #' @param authentication what to do if the site exists but the
@@ -508,31 +537,42 @@ server_api_post <- function(url, repository, authentication, query, quiet = FALS
 #'
 #' @noRd
 server_api_get <- function(url, resource, authentication, quiet = FALSE, max_seconds = 20) {
-  
+
   sGET <- safely(httr::GET)
-  
+
   resource_url <- ""
-  
+
   if (resource == "protocol")
     resource_url <- paste0(url, "/protocol")
-  
+
   res <- sGET(
     url = resource_url,
     config = authentication,
     timeout(max_seconds)
   )
   
+  if (!curl::has_internet()) {
+    message("No internet connection.")
+    return(invisible(NULL))
+  }
+
   if (is.null(res$result) || ((httr::status_code(res$result) %/% 200) != 1)) {
-    
-    if (is.null(res$result))
-      stop(call. = FALSE, server_no_response(resource_url))
-    
-    if (((httr::status_code(res$result) %/% 200) != 1)) {
-      if (!quiet) stop(call. = FALSE, get_message_from_status_code(httr::status_code(res$result), url, resource))
+
+    if (is.null(res$result)) {
+      message(server_no_response(resource_url)) #stop(call. = FALSE, server_no_response(resource_url))
+      return(invisible(NULL)) #return(res$result)
     }
-    
+
+    if (((httr::status_code(res$result) %/% 200) != 1)) {
+      if (!quiet) {
+        #stop(call. = FALSE, get_message_from_status_code(httr::status_code(res$result), url, resource))
+        message(get_message_from_status_code(httr::status_code(res$result), url, resource))
+        return(invisible(NULL)) #return(res$result)
+      }
+    }
+
   } else {
     return(httr::content(res$result))
   }
-  
-}
\ No newline at end of file
+
+}
